Embed Module
============

The Embed module provides a simple, function-like API for text embeddings with support for
structured parameter configuration.

Core Classes
------------

Embed Client
~~~~~~~~~~~~

.. autoclass:: lexilux.embed.Embed
   :members:
   :undoc-members:
   :show-inheritance:

Result Models
~~~~~~~~~~~~~

.. autoclass:: lexilux.embed.EmbedResult
   :members:
   :undoc-members:
   :show-inheritance:

Parameter Configuration
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: lexilux.embed_params.EmbedParams
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

